@@ -1,12 +1,17 @@
+import django
 from django.utils.importlib import import_module
 import imp
 import os
 import sys
 from .exceptions import InvalidSettingsFactory, SettingsFactoryDoesNotExist
+from .decorators import callable_setting
+from .settings import DjangoDefaults
 from .switching import switcher
+from cbsettings.pkgmeta import *
 
 
 ENVIRONMENT_VARIABLE = 'DJANGO_SETTINGS_FACTORY'
+DJANGO_SETTINGS_MODULE = django.conf.ENVIRONMENT_VARIABLE
 
 
 def configure(factory=None, **kwargs):
@@ -35,19 +40,27 @@ def configure(factory=None, **kwargs):
 
         # Create the settings module.
         parts = settings_dict['SETTINGS_MODULE'].split('.')
-        for module_name in map(lambda x: '.'.join(x), [parts[0:i + 1] for i in
-                range(len(parts))]):
+        parent_module = None
+        for i in range(len(parts)):
+            module_fullname = '.'.join(parts[:i + 1])
+            module_name = parts[i]
             try:
-                module = __import__(module_name, fromlist=[''])
+                module = __import__(module_fullname, fromlist=[''])
             except ImportError:
-                module = imp.new_module(module_name)
-                sys.modules[module_name] = module
+                module = imp.new_module(module_fullname)
+                sys.modules[module_fullname] = module
+
+            if parent_module:
+                setattr(parent_module, module_name, module)
+            parent_module = module
 
         # Unroll the settings into a new module.
         for k, v in settings_dict.items():
+            if callable(v) and not getattr(v, 'is_callable_setting', False):
+                v = v()
             setattr(module, k, v)
 
-        os.environ['DJANGO_SETTINGS_MODULE'] = settings_dict['SETTINGS_MODULE']
+        os.environ[DJANGO_SETTINGS_MODULE] = settings_dict['SETTINGS_MODULE']
 
         return mod, settings_obj
     else:
